@@ -1,6 +1,6 @@
 from __future__ import absolute_import, print_function
 
-from .Crops import Crops
-from .Crops2D import Crops2D
+from .Crops import *
+
 from .NPZCrops import *
 
